@@ -5,9 +5,6 @@ var colors = require('colors/safe'),
 
 function main (cxt) {
 
-// : ] 0 STATE ! ;
-// : [ -1 STATE ! ; IMMEDIATE
-
 // IMMEDIATE
     def('immediate', function () {
         var len = this.L.length;
@@ -90,6 +87,23 @@ function main (cxt) {
         console.log(colors.green(w) + ': ' + this[this.O[w].index]);
     }, cxt);
 
+// 6.1.0070 ' “tick” (CORE)
+// ( “<spaces>name” -- xt )
+// Skip leading space delimiters. Parse name delimited by a space.
+// Find name and return xt, the execution token for name. An ambiguous
+// condition exists if name is not found.
+
+    def('\'', function () {
+        var w = this.io.word('\\s');
+        var wordLink = this.O[w.toLowerCase()];
+        if (wordLink) {
+           this.dpush(wordLink.index);
+        } else {
+            console.log('word: ' + w + ' is not defined');
+            throw new Error;
+        }
+    }, cxt);
+
 }
 
 module.exports = main;
