@@ -1,61 +1,13 @@
 'use strict';
 
 var word = require('./word'),
+    ast = require('./ast'),
     estraverse = require('estraverse');
 
 var Syntax = estraverse.Syntax;
 
-function dpush (e) {
-    return {
-        type: Syntax.ExpressionStatement,
-        expression: {
-            type: Syntax.CallExpression,
-            callee: {
-                type: Syntax.MemberExpression,
-                computed: false,
-                object: {
-                    type: Syntax.ThisExpression
-                },
-                property: {
-                    type: Syntax.Identifier,
-                    name: 'dpush'
-                }
-            },
-            arguments: [
-                {
-                    type: Syntax.Literal,
-                    value: Number(e),
-                    raw: e
-                }
-            ]
-        }
-    };
-}
-
-function callword (e) {
-    return {
-        type: Syntax.ExpressionStatement,
-        expression: {
-            type: Syntax.CallExpression,
-            callee: {
-                type: Syntax.MemberExpression,
-                computed: true,
-                object: {
-                    type: Syntax.ThisExpression
-                },
-                property: {
-                    type: Syntax.Literal,
-                    value: e,
-                    raw: e + ''
-                }
-            },
-            arguments: []
-        }
-    };
-}
-
 function interpret (str, done) {
-    var w, wordLink, num;
+    var w, wordLink, num, lines;
 
     this.io.buf = str;
     this.io.ptr = 0;
@@ -74,15 +26,18 @@ function interpret (str, done) {
                 if (wordLink.immediate) {
                     this[wordLink.index]();
                 } else {
-                   this.pos.push(callword(wordLink.index));
+                   this.pos.push(ast.callword(wordLink.index));
                }
             } else {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
+                    lines = this.io.buf.slice(0, this.io.ptr).split('\n');
+                    console.log('Error in line: %s', lines.length - 1);
                     console.log('word: ' + w + ' is not defined');
+                    console.log(lines.pop());
                     throw new Error;
                 } else {
-                    this.pos.push(dpush(num));
+                    this.pos.push(ast.dpush(num));
                 }
             }
         } else { // interpret
@@ -91,7 +46,10 @@ function interpret (str, done) {
             } else {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
+                    lines = this.io.buf.slice(0, this.io.ptr).split('\n');
+                    console.log('Error in line: %s', lines.length - 1);
                     console.log('word: ' + w + ' is not defined');
+                    console.log(lines.pop());
                     throw new Error;
                 } else {
                     this.dpush(num);
