@@ -116,23 +116,23 @@ function stack (cxt) {
     });
 
     // x1 -- x2
-    '0<:t<0;0<>:t!==0;0>:t>0;0=:t===0;1+:t+1;1-:t-1;2*:t<<1;2/:t>>1;abs:Math.abs(t);cell+:t+4;cells:t*4;char+:t+1;chars:t;invert:~t;negate:-t'
+    ' 0< # ((t < 0) ? -1 : 0) ; 0<> # ((t !== 0) ? -1 : 0) ; 0> # ((t > 0) ? -1 : 0) ; 0= # ((t === 0) ? -1 : 0) ; 1+ # (t + 1) ; 1- # (t - 1) ; 2* # (t << 1) ; 2/ # (t >> 1) ; abs # Math.abs(t) ; cell+ # (t + 4) ; cells # (t * 4) ; char+ # (t + 1) ; chars # t ; invert # (t ^ -1) ; negate # (-t) '
     .split(';')
-    .map(function (e) { return e.split(':'); })
+    .map(function (e) { return e.split('#'); })
     .forEach(function (e) {
         var fn;
-        eval('fn = function () { var t = this.dpop(); this.dpush(' + e[1] + '); };');
-        def(e[0], fn, cxt);
+        eval('fn = function () { var t = this.dpop(); this.dpush(' + e[1] + '| 0); };');
+        def(e[0].trim(), fn, cxt);
     });
 
     // x1 x2 -- x3
-    '+:n+t;-:n-t;*:n*t;/:n/t;<>:t!==n;and:n&t;=:n===t;>:n>t;<:n<t;lshift:n<<t;max:Math.max(t,n);min:Math.min(t,n);mod:n%t;or:n|t;rshift:n>>t;u<:n<t;xor:n^t;u>:n>t'
+    ' + # (n + t) ; - # (n - t) ; * # (n * t) ; / # (n / t) ; <> # ((t !== n) ? -1 : 0) ; and # (n & t) ; = # ((n === t) ? -1 : 0) ; > # ((n > t) ? -1 : 0) ; < # ((n < t) ? -1 : 0) ; lshift # (n << t) ; max # (Math.max(t, n)) ; min # (Math.min(t, n)) ; mod # (n % t) ; or # (n | t) ; rshift # (n >>> t) ; u< # ((n < t) ? -1 : 0) ; xor # (n ^ t) ; u> # ((n > t) ? -1 : 0) '
     .split(';')
-    .map(function (e) { return e.split(':'); })
+    .map(function (e) { return e.split('#'); })
     .forEach(function (e) {
         var fn;
-        eval('fn = function () { var t = this.dpop(); var n = this.dpop(); this.dpush(' + e[1] + '); };');
-        def(e[0], fn, cxt);
+        eval('fn = function () { var t = this.dpop(); var n = this.dpop(); this.dpush(' + e[1] + ' | 0); };');
+        def(e[0].trim(), fn, cxt);
     });
 
 }
